==> libstdc++-2.90.3.tar.gz: libstdc++-2.90.3/bits/std_ios.h <==
// Iostreams base classes -*- C++ -*-

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882: 27.4  Iostreams base classes
//

#ifndef _CPP_IOS
#define _CPP_IOS	1

#include <bits/c++config.h>
#include <bits/stl_config.h>
#include <bits/std_exception.h>
#include <bits/std_iosfwd.h>
#include <bits/stl_alloc.h>  /* allocator for string, vector */
#include <bits/std_iterator.h>
#include <bits/std_climits.h>
#include <bits/utility.h>
#include <bits/std_cwchar.h>
#include <bits/stl_string_fwd.h>
#include <bits/char_traits.h>
#include <bits/basic_string.h>   /* but not basic_string.tcc */
#include <bits/std_stdexcept.h>
#include <bits/std_vector.h>
#include <bits/std_cctype.h>
#include <bits/std_typeinfo.h>  /* for bad_cast */
#include <bits/loccore.h>  /* but not loccore.tcc */
#include <bits/ios_base.h>
#include <bits/std_streambuf.h> // for pubimbue method

#include <bits/std_ctime.h>  // for struct tm
#include <bits/locfacets.h>
#include <bits/basic_ios.h>
  
#endif	/* _CPP_IOS */

==> libstdc++-2.90.6.tar.gz: libstdc++-2.90.6/bits/std_ios.h <==
// Iostreams base classes -*- C++ -*-

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882: 27.4  Iostreams base classes
//

#ifndef _CPP_IOS
#define _CPP_IOS	1

#include <bits/std_iosfwd.h>
#ifdef _GLIBCPP_USE_LIBIO
extern "C" { 
#  include <libio.h> 
}
#else
#warning "need_to_include_another_interface_file_for_underlying_IO_library"
#endif
#include <bits/char_traits.h> 	// For char_traits, streamoff, streamsize, fpos
#include <bits/std_exception.h> // For ios_base::failure
#include <bits/stl_string_fwd.h>// For string.
#include <bits/std_cstdio.h> 	// For SEEK_SET, SEEK_CUR, SEEK_END
# include <bits/localefwd.h>	// For class locale
#include <bits/ios_base.h>
#include <bits/std_streambuf.h> // For ios_base definitions.
#include <bits/basic_ios.h>

#endif	/* _CPP_IOS */
